summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorStanislaw Halik <sthalik@misaki.pl>2016-06-21 11:15:33 +0200
committerStanislaw Halik <sthalik@misaki.pl>2016-06-21 11:15:33 +0200
commitdee8de57ad54c0c1cf46b63066de571c8cb98470 (patch)
tree136b6d3725ab9c9315cdc00db8fa12be440b4556
parentf434ba5aa24870582059725e72f5595c839ad3e0 (diff)
filter/ewma: change delta smoothing constant back
-rw-r--r--filter-ewma2/ftnoir_filter_ewma2.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/filter-ewma2/ftnoir_filter_ewma2.h b/filter-ewma2/ftnoir_filter_ewma2.h
index 328279ac..c5e4b241 100644
--- a/filter-ewma2/ftnoir_filter_ewma2.h
+++ b/filter-ewma2/ftnoir_filter_ewma2.h
@@ -26,8 +26,8 @@ public:
FTNoIR_Filter();
void filter(const double *input, double *output);
private:
- // Deltas are smoothed over the last 1/20sec.
- const double delta_RC = 1./20;
+ // Deltas are smoothed over the last 1/60sec.
+ const double delta_RC = 1./60;
// Noise is smoothed over the last 60sec.
const double noise_RC = 60.0;
double last_delta[6];